Struct CaskWriterConfigBuilder

pub struct CaskWriterConfigBuilder { /* private fields */ }
Helper to create CaskWriterConfig

Implementations

Source

impl CaskWriterConfigBuilder

pub fn with_filename(self, filename: &str) -> Self

Specifies the filename

pub fn with_timestamp_filename(self, id: &str) -> Self

Sets the filename based on an identifier and the current timestamp

pub fn with_channel(self, channel: CaskChannel) -> Self

Enables a channel to be recorded into this cask

pub fn with_channels<'a, I: IntoIterator<Item = CaskChannel>>( self, channels: I, ) -> Self

Enables multiple channels to be recorded into this cask

pub fn without_channel(self, topic: &str) -> Self

Disables a previously enabled channel to not be recorded