pub struct CaskWriterConfigBuilder { /* private fields */ }Expand description
Helper to create CaskWriterConfig
Implementations
Sourceimpl CaskWriterConfigBuilder
impl CaskWriterConfigBuilder
Sourcepub fn with_filename(self, filename: &str) -> Self
pub fn with_filename(self, filename: &str) -> Self
Specifies the filename
Sourcepub fn with_timestamp_filename(self, id: &str) -> Self
pub fn with_timestamp_filename(self, id: &str) -> Self
Sets the filename based on an identifier and the current timestamp
Sourcepub fn with_channel(self, channel: CaskChannel) -> Self
pub fn with_channel(self, channel: CaskChannel) -> Self
Enables a channel to be recorded into this cask
Sourcepub fn with_channels<'a, I: IntoIterator<Item = CaskChannel>>(
self,
channels: I,
) -> Self
pub fn with_channels<'a, I: IntoIterator<Item = CaskChannel>>( self, channels: I, ) -> Self
Enables multiple channels to be recorded into this cask
Sourcepub fn without_channel(self, topic: &str) -> Self
pub fn without_channel(self, topic: &str) -> Self
Disables a previously enabled channel to not be recorded